import { Plugin } from 'vite';

declare type Page = {
    /**
     * Path to a component to create the dev page for
     *
     * @example './components/MyButton/*.vue'
     */
    component: string;
    /**
     * Path to the example vue files of a component to put on the dev page
     *
     * @example './components/MyButton/*.example.vue'
     */
    examples: string | string[];
    /**
     * Defaults to the filename
     */
    title?: string;
};
declare type NormalizedPage = {
    title: string;
    /** Absolute path of the component */
    component: string;
    /** Absolute path of example files */
    examples: string[];
};
declare type Options = {
    /**
     * Path to extract components from to create dev pages for
     *
     * @example './components/*\/*.vue'
     */
    components?: string;
    /**
     * Path to extract component examples from to put on each dev page
     *
     * @example './components/*\/*.example.vue'
     */
    componentExamples?: string;
    /**
     * The base path the generated routes should be nested under as children.
     *
     * @example '/dev'
     */
    base?: string;
    /**
     * Navbar title
     */
    title?: string;
    /**
     * Navbar logo
     */
    logo?: string;
    pages?: Page[];
    cacheDir?: string;
    getPath?: (slug: string) => string;
};
declare const plugin: (options: Options) => Plugin[];

export { NormalizedPage, Options, Page, plugin as default };
